@@ -1,6 +1,7 @@
 #include <R_ext/RS.h>
 #include <stdlib.h> // for NULL
 #include <R_ext/Rdynload.h>
+#include <R.h>
 
 /* FIXME: 
    Check these declarations against the C/Fortran source code.
@@ -10,6 +11,12 @@
 extern void F77_NAME(dllrocdirect)(void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *);
 extern void F77_NAME(dllrocinduced)(void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *);
 
+
+void F77_SUB(rndstart)(void) { GetRNGstate(); }
+void F77_SUB(rndend)(void) { PutRNGstate(); }
+double F77_SUB(unifrnd)(void) { return unif_rand(); }
+
+
 static const R_FortranMethodDef FortranEntries[] = {
     {"dllrocdirect",  (DL_FUNC) &F77_NAME(dllrocdirect),  36},
     {"dllrocinduced", (DL_FUNC) &F77_NAME(dllrocinduced), 29},
